Crate jingle_sleigh

Crate jingle_sleigh 

Re-exports

pub use display::JingleDisplay;
pub use display::JingleDisplayWrapper;

Modules

branch
context
display
op_ref

Structs

Disassembly
A display-friendly representation of an instruction, generated by SLEIGH. Sleigh does not provide any tokenization of instruction operands, so they are all contained as a string representation in the args attribute.
IndirectVarNode
Instruction
A rust representation of a SLEIGH assembly instruction
OpCode
PcodeOpRef
PcodeOpRef — ergonomic wrapper for p-code operations stored or borrowed.
SleighArchInfo
SpaceInfo
Information about a PCODE address space modeled by SLEIGH. Internally, jingle uses indices to refer unambiguously and efficiently to spaces. This has the advantage of drastically reducing the amount of alloc/drop churn when working with jingle but has a cost: in order to use “nice” things like the names of spaces, you need to have a way to refer to a SpaceInfo object.
SpaceType
VarNode
A VarNode is SLEIGH’s generalization of an address. It describes a sized-location in a given memory space.

Enums

GeneralizedVarNode
JingleSleighError
An error (usually from across the FFI boundary) in something involving sleigh
PcodeOperation
SleighEndianness
What program-analysis library wouldn’t be complete without an enum for endianness?

Functions

create_varnode