pub struct PcodeOpRef<'a>(/* private fields */);Expand description
PcodeOpRef — ergonomic wrapper for p-code operations stored or borrowed.
PcodeOpRef encapsulates either a borrowed reference to a PcodeOperation or an
owned PcodeOperation (internally using Cow). This type is intended to be
the canonical p-code operation reference type used by the sleigh crate.
Methods from Deref<Target = PcodeOperation>
pub fn branch_destination(&self) -> Option<PcodeBranchDestination>
pub fn opcode(&self) -> OpCode
pub fn terminates_block(&self) -> bool
pub fn has_fallthrough(&self) -> bool
pub fn inputs(&self) -> Vec<GeneralizedVarNode>
pub fn output(&self) -> Option<GeneralizedVarNode>