A display-friendly representation of an instruction, generated by SLEIGH. Sleigh does not
provide any tokenization of instruction operands, so they are all contained as a string
representation in the args attribute.
Information about a PCODE address space modeled by SLEIGH. Internally, jingle uses indices
to refer unambiguously and efficiently to spaces.
This has the advantage of drastically reducing the amount of alloc/drop churn when working with
jingle but has a cost: in order to use “nice” things like the names of spaces, you need to have
a way to refer to a SpaceInfo object.